package com.example.demo.ageRatings.service;

import java.util.List;
import java.util.stream.StreamSupport;

import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.example.demo.ageRatings.model.AgeRatingEntity;
import com.example.demo.ageRatings.repository.AgeRatingRepository;
import com.example.demo.core.error.NotFoundException;

@Service
public class AgeRatingService {
    private final AgeRatingRepository repository;

    public AgeRatingService(AgeRatingRepository repository) {
        this.repository = repository;
    }

    @Transactional(readOnly = true)
    public List<AgeRatingEntity> getAll() {
        return StreamSupport.stream(repository.findAll().spliterator(), false).toList();
    }

    @Transactional(readOnly = true)
    public AgeRatingEntity get(Long id) {
        return repository.findById(id)
                .orElseThrow(() -> new NotFoundException(AgeRatingEntity.class, id));
    }

    @Transactional
    public AgeRatingEntity create(AgeRatingEntity entity) {
        if (entity == null) {
            throw new IllegalArgumentException("Entity is null");
        }

        return repository.save(entity);
    }

    @Transactional
    public AgeRatingEntity update(Long id, AgeRatingEntity entity) {
        final AgeRatingEntity existsEntity = get(id);

        existsEntity.setName(entity.getName());
        return repository.save(existsEntity);
    }

    @Transactional
    public AgeRatingEntity delete(Long id) {
        final AgeRatingEntity existsEntity = get(id);
        repository.delete(existsEntity);

        return existsEntity;
    }

    public void deleteAll() {
        repository.deleteAll();
    }
}
