package com.example.demo.types.service;

import java.util.List;
import java.util.stream.StreamSupport;

import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.example.demo.core.error.NotFoundException;
import com.example.demo.types.model.TypeEntity;
import com.example.demo.types.repository.TypeRepository;

@Service
public class TypeService {
    private final TypeRepository repository;

    public TypeService(TypeRepository repository) {
        this.repository = repository;
    }

    @Transactional(readOnly = true)
    public List<TypeEntity> getAll() {
        return StreamSupport.stream(repository.findAll().spliterator(), false).toList();
    }

    @Transactional(readOnly = true)
    public TypeEntity get(Long id) {
        return repository.findById(id)
                .orElseThrow(() -> new NotFoundException(TypeEntity.class, id));
    }

    @Transactional
    public TypeEntity create(TypeEntity entity) {
        if (entity == null) {
            throw new IllegalArgumentException("Entity is null");
        }

        return repository.save(entity);
    }

    @Transactional
    public TypeEntity update(Long id, TypeEntity entity) {
        final TypeEntity existsEntity = get(id);

        existsEntity.setName(entity.getName());
        return repository.save(existsEntity);
    }

    @Transactional
    public TypeEntity delete(Long id) {
        final TypeEntity existsEntity = get(id);
        repository.delete(existsEntity);

        return existsEntity;
    }

    public void deleteAll() {
        repository.deleteAll();
    }
}
